@@ -1,13 +1,13 @@
 package tkpingLib;
 ###############################################################################
 ## @(#)FILE: tkpingLib.pm - Perl package of common routines & constants
-## @(#)$Source: tkping-0.1.0/tkpingLib.pm $
+## @(#)$Source: /cvs/stephen/personal/tkping/tkpingLib.pm,v $
 ## ============================================================================
 ##  Description:
 ##
 ##   This file is a repository of generally useful perl-functions.
-##   It may be used by including a "use tkpingLib;" statement in your perl 
-##   scripts. 
+##   It may be used by including a "use tkpingLib;" statement in your perl
+##   scripts.
 ##
 ###############################################################################
 
@@ -32,7 +32,7 @@ require Exporter;
 
 @ISA = qw(Exporter);
 
-$VERSION = "1.01";
+$VERSION = 1.10;
 
 @EXPORT = qw(
 	&VerboseMsg
@@ -179,7 +179,7 @@ sub Msg(@)
 		$ARGC = @ARGV;
 	}
 	my ($msgText) = @ARGV;	# text is remainder of list
-	
+
 	if( $nuline ) {
 		if($noId) {
 			print STDERR $msgText,"\n";
@@ -321,7 +321,7 @@ sub ProgressMsg(@)
 		$ARGC = @ARGV;
 	}
 	my ($msgText) = @ARGV;	# text is remainder of list
-	
+
 	if(! defined $main::opt_silent) {
 		if($noId) {
 			print STDOUT $msgText,"\n";
@@ -329,7 +329,7 @@ sub ProgressMsg(@)
 			print STDOUT $prefixText,"${main::NAME}: ",$msgText,"\n";
 		}
 	}
-	
+
 	if($isLogging && $logToo) {
 		if($prefixText ne "") {
 			LogMsg(-nl,"$msgText");
@@ -341,19 +341,19 @@ sub ProgressMsg(@)
 			}
 		}
 	}
-	
+
 	if($toFileToo) {
 		if($modeAppend) {
-			open OUTFILE, ">>$outFspec" or 
+			open OUTFILE, ">>$outFspec" or
 				SwengFatalMsg("Unable to append to [$outFspec], Aborting!!\007");
 				return if(UTFatalOccurred());  # return if under unit-test!
 		} else {
-			open OUTFILE, ">$outFspec" or 
+			open OUTFILE, ">$outFspec" or
 				SwengFatalMsg("Unable to write to [$outFspec], Aborting!!\007");
 				return if(UTFatalOccurred());  # return if under unit-test!
 		}
 		print OUTFILE $prefixText,"${main::NAME}: ",$msgText,"\n";
-		close OUTFILE or 
+		close OUTFILE or
 			SwengFatalMsg("ERROR- Unable to close [$outFspec], Aborting!!\007");
 			return if(UTFatalOccurred());  # return if under unit-test!
 	}
@@ -395,7 +395,7 @@ sub DebugMsg(@)
 
 
 ##-----------------------------------------------------------------------------
-## FUNCTION: 
+## FUNCTION:
 ##   SwengFatalMsg -- Print the given arguments to STDERR (prefixed by "$NAME: ").
 ##  				  and then exit.
 ##
@@ -425,8 +425,8 @@ sub SwengFatalMsg(@)
 ##   $exit_status: value to pass to exit() when exiting the script
 ##
 ## PRECONDITIONS:
-##   The global list @TKPING_LIB_ABORT_FCN_AR should contain the name of 
-##   zero or morecleanup functions to invoke before exiting the script. 
+##   The global list @TKPING_LIB_ABORT_FCN_AR should contain the name of
+##   zero or morecleanup functions to invoke before exiting the script.
 ##   This list isinitially empty, but may be populated by the user if
 ##   so desired.
 ##
@@ -558,7 +558,7 @@ sub SetLog($)
 		SwengFatalMsg("SetLog(): Attempt to open log 2nd time, aborted!");
 		return if(UTFatalOccurred());  # return if under unit-test!
 	}
-	open LOGFILE, ">>$logFspec" or 
+	open LOGFILE, ">>$logFspec" or
 		SwengFatalMsg("Unable to append to [$logFspec], Aborting!!\007");
 		return if(UTFatalOccurred());  # return if under unit-test!
         select(LOGFILE); $| = 1; select(STDOUT);
@@ -587,7 +587,7 @@ sub EndLog()
 	}
 	LogMsg("Complete.");
 	$tkpingLib::isLogging=0;	# set INactive flag!
-	close LOGFILE or 
+	close LOGFILE or
 		SwengFatalMsg("ERROR- Unable to close [$tkpingLib::logFspec], Aborting!!\007");
 		return if(UTFatalOccurred());  # return if under unit-test!
 }
@@ -604,7 +604,7 @@ sub EndLog()
 ##  		produces:  $timeStamp = "25May97-12:04:30"
 ##
 ##-----------------------------------------------------------------------------
-sub RunDate() 
+sub RunDate()
 {
 	my $runDateTxt = &GetDateTime( 'DDMMMYY-HH:MM:SS' );
 	return $runDateTxt;
@@ -621,7 +621,7 @@ sub RunDate()
 ##  		(prevents fatal errors from exiting!)
 ##
 ##-----------------------------------------------------------------------------
-sub EnableUnitTest() 
+sub EnableUnitTest()
 {
 	$unitTestMode=1;
 	$traceCalls=1;
@@ -640,7 +640,7 @@ sub EnableUnitTest()
 ##  		(used to force exit under unit-test conditions)
 ##
 ##-----------------------------------------------------------------------------
-sub UTFatalOccurred() 
+sub UTFatalOccurred()
 {
 	if(not $unitTestMode) {
 		DebugMsg("UTFatalOccurred() NOT in UT mode...") if($traceCalls);;
@@ -666,20 +666,20 @@ sub UTFatalOccurred()
 ##  		 earlier than less-specific ( eg., HH:MM:SS before HH:MM )
 ##
 ##  	2) $mon has range (0..11) and $wday has range (0..6)
-## 
+##
 ## ----------------------------------------------------------
 sub GetDateTime($)
 {
 	my $formatSpec  = shift;
 
-	my( @monthNmAr ) = ( "Jan", "Feb", "Mar", "Apr", "May", "Jun", 
+	my( @monthNmAr ) = ( "Jan", "Feb", "Mar", "Apr", "May", "Jun",
 	                    "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" );
 
 	my( @dayNmAr ) = ( "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat" );
 
 	my $dateTimeResult = "GetDateTime::INVALID_FORMAT_ID";
 
-	my( $sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) 
+	my( $sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst)
 			= localtime( time );
 
 	# Workaround Perl bug for Y2K
@@ -689,41 +689,48 @@ sub GetDateTime($)
 	# ----------------------------------------------------------
 	#  'Switch' construct ... create output based on $formatSpec
 	# ----------------------------------------------------------
-	for( $formatSpec ) 
+	for( $formatSpec )
 	{
-		/DDMMMYY-HH:MM:SS/ and do 
+		/DDMMMYY-HH:MM:SS/ and do
 		{
 			$dateTimeResult = sprintf( "%2.2d%3.3s%2.2d-%2.2d:%2.2d:%2.2d",
 			                      $mday, $monthNmAr[ $mon ], $year, $hour, $min, $sec );
 			last;
 		};
 
+		/HH:MM_DDDc_DD_MMM_YYYY/ and do
+		{
+			$dateTimeResult = sprintf( "%02d:%02d %3.3s, %02d %3.3s 20%02d",
+			                      $hour, $min, $dayNmAr[ $wday ], $mday, $monthNmAr[ $mon ], $year );
+			last;
+		};
+
 		/YYMMDD_HH:MM/ and do
 		{
-			$dateTimeResult = sprintf( "%02d%02d%02d_%02d:%02d", 
+			$dateTimeResult = sprintf( "%02d%02d%02d_%02d:%02d",
 			                      $year, $mon+1, $mday, $hour, $min );
 			last;
 		};
 
-		/HH:MM:SS/ and do 
+		/HH:MM:SS/ and do
 		{
 			$dateTimeResult = sprintf( "%02d:%02d:%02d", $hour, $min, $sec );
 			last;
 		};
 
-		/HH:MM/ and do 
+		/HH:MM/ and do
 		{
 			$dateTimeResult = sprintf( "%02d:%02d", $hour, $min );
 			last;
 		};
 
-		/YYMMDD/ and do 
+		/YYMMDD/ and do
 		{
 			$dateTimeResult = sprintf( "%02d%02d%02d", $year, $mon +1, $mday );
 			last;
 		};
 
-		/DD-MMM-YY/ and do 
+		/DD-MMM-YY/ and do
 		{
 			$dateTimeResult = sprintf( "%02d-%03s-%02d", $mday, $monthNmAr[ $mon ], $year );
 			last;
@@ -739,7 +746,7 @@ sub GetDateTime($)
 
 ##-----------------------------------------------------------
 ## FUNCTION:
-##   Trim()  -- remove leading and trailing whitespace from 
+##   Trim()  -- remove leading and trailing whitespace from
 ##  	 input string
 ##
 ## SYNOPSIS:
@@ -757,7 +764,7 @@ sub Trim($)
 
 ##-----------------------------------------------------------
 ## FUNCTION:
-##   Basename()  -- remove directory path 
+##   Basename()  -- remove directory path
 ##                  (& optional suffix) from input pathname
 ##
 ## SYNOPSIS:
@@ -768,7 +775,7 @@ sub Basename($;$)
 {
 	my $fileBasename = shift;
 	my $extension = shift;
-	
+
 	if(!defined $extension) {
 		$extension = "";
 	} else {
@@ -802,7 +809,7 @@ sub Basename($;$)
 sub Dirname($)
 {
 	my $fspec = shift;
-	
+
 	my $fileDirname;
 	my $fileName;
 
@@ -837,24 +844,24 @@ sub Dirname($)
 ##   @array = &File2Array(filename);
 ##
 ##-----------------------------------------------------------------------------
-sub File2Array($) 
+sub File2Array($)
 {
 	my $filespec = shift;
 	my @newAr = ();
-	
+
 	DebugMsg("File2Array() loading array from $filespec");
-	
+
 	#  ensure our data file exists and open it
 	open AR_SRC_FILE,"<$filespec" or
 		FatalMsg("Unable to read [$filespec]: $!, Aborting!!\007");
-	
+
 	#  load our data file into the array
 	@newAr = <AR_SRC_FILE>;	# grab all lines of file
 
 	#  close our data file
 	close AR_SRC_FILE or
 		FatalMsg("Unable to close [$filespec]: $!, Aborting!!\007");
-	
+
 	#  return our array
 	chomp @newAr;	# remove newlines...
 	my $lineCt = @newAr;
@@ -875,17 +882,17 @@ sub File2Array($)
 ##   &Array2File(filename,@array);
 ##
 ##-----------------------------------------------------------------------------
-sub Array2File($@) 
+sub Array2File($@)
 {
 	my $filespec = shift;
 	my @argAr = @_;
 	my $lineCt = @argAr;
 	DebugMsg("Array2File() writing array ($lineCt element(s)) to $filespec");
-	
+
 	#  ensure our data file exists and open it
 	open AR_DST_FILE,">$filespec" or
 		FatalMsg("Unable to write to [$filespec]: $!, Aborting!!\007");
-	
+
 	#  load our data file into the array
 	foreach $ele (@argAr) {
 		print AR_DST_FILE $ele,"\n";	# write each element to our file
@@ -907,7 +914,7 @@ sub Array2File($@)
 ###
 ###    Comments (comment lines or right edge of lines) are stripped before
 ###      the file is parsed)
-###   
+###
 ###    Blank lines terminate a list (hash or array), multiples are ignored
 ###
 ###    There are two value-set forms:  Hash's and Array's (perl'esq)  They are
@@ -918,38 +925,38 @@ sub Array2File($@)
 ###        ~Hs   - is a hash
 ###        ~Ar   - is an array
 ###
-###    An array (~Ar) is specified in one of two forms: (the presence of a 
+###    An array (~Ar) is specified in one of two forms: (the presence of a
 ###    leading '[' indicates which form to use.)
-###    
+###
 ###    [{keyname}Ar]               # head a value list
 ###    value one                   #  one value per line
 ###    value two                   #  one value per line
-###      ...etc...                 #  
+###      ...etc...                 #
 ###    {blank line}                # ends value list
 ###
 ###    [{keyname}Ar]               # head a value list
 ###    [000] = value one           #  one value per line (NOTE leading zeros and fixed width)
 ###    [001] = value two           #  one value per line
 ###    [002] = value three         #  one value per line
-###     ...etc...                  #  
+###     ...etc...                  #
 ###    {blank line}                # ends value list
 ###
 ###        NOTE: this second array form is what the file would look like if written
-###        by the tkpingLib::Hash2Ini() library routine.  This form is accepted 
+###        by the tkpingLib::Hash2Ini() library routine.  This form is accepted
 ###        primarily so that the reader-side can read the written form of these files.
 ###
 ###    A hash (~Hs) is specified in only one form:
-###    
+###
 ###    [{keyname}Hs]               # head a value list
 ###    key1 = value one            #  one value per line (NOTE leading zeros and fixed width)
 ###    key2 = value two            #  one value per line
 ###    key3 = value three          #  one value per line
-###      ...etc...                 # 
+###      ...etc...                 #
 ###    {blank line}                # ends value list
-###    
+###
 ###  The final feature is that hashs can have simple key-value pairs or may
 ###   contain key-value pairs that effectively point to other hash's and array's.
-###   
+###
 ###  To point from a hash to a hash:
 ###     [topHs]
 ###     childHs = theNamedHs
@@ -976,7 +983,7 @@ sub Array2File($@)
 ###
 ###  NOTE: arrays can NOT point to arrays or hashs
 ###
-###  NOTE2:  there is no limit (well, maybe memory on your system? ;-) to the 
+###  NOTE2:  there is no limit (well, maybe memory on your system? ;-) to the
 ###     depth you may cascade these references.
 ###
 ###  NOTE3:  the presence of a special hash named 'ConstantsHs' will cause
@@ -985,7 +992,7 @@ sub Array2File($@)
 ###          .ini file by moving the constants from a shared source file to
 ###          the .ini file which is already shared! -Stephen
 ###
-###  SPECIAL WARNING:  watch out for cycles!  You must break them by by using 
+###  SPECIAL WARNING:  watch out for cycles!  You must break them by by using
 ###    simple key names for one of the hash's!!
 ###
 ###      - Stephen M. Moraco t590-5714  mailto:stephen@cos.agilent.com
@@ -1052,7 +1059,7 @@ sub genHsArIniFile(*$$)
 
     push @keyListAr,$fileListHsNm;  #  put top key, then chase to get rest
     scanForKeys($fileListHsNm,\@keyListAr,$namespace);
-    
+
     my $keyListCt = @keyListAr;
     ###  DebugMsg("Save $keyListCt keys to ini file");
 
@@ -1071,7 +1078,7 @@ sub genHsArIniFile(*$$)
                 if ((($subKey =~ /Hs$/) && ($value =~ /Hs$/)) ||
                     (($subKey =~ /Ar$/) && ($value =~ /Ar$/))) {
                     # if it's a symbolic hash or array ref, make the value
-                    # namespace-neutral 
+                    # namespace-neutral
                     $value =~ s/^$namespace//;
                 }
                 print HSDUMP_OUT "$subKey = $value\n";
@@ -1119,33 +1126,33 @@ sub Hash2IniFile($$;$)
     $namespace .= "::" if ($namespace !~ /::$/);
 
     DebugMsg("Hash2IniFile() writing hashes/arrays from \%${namespace}$topHashHsNm to $outFName");
-    
+
     open(HSDUMP_OUT,">$outFName") or
       SwengFatalMsg("Can't open [$outFName] for write: $!");
     return if (UTFatalOccurred());  # return if under unit-test!
-    
+
 	my ($realId,$effId) = tkpingLib::GetUserNames();
-    my $extraIdStr = ($realId ne $effId) ? sprintf("(as %s)",$effId) : "";    
-    
+    my $extraIdStr = ($realId ne $effId) ? sprintf("(as %s)",$effId) : "";
+
     my $dateTimeStr = tkpingLib::GetDateTime("YYMMDD_HH:MM");
 
     print HSDUMP_OUT "# $sep\n";
     print HSDUMP_OUT "#         FILE:  $outFName\n";
     print HSDUMP_OUT "#    Namespace:  $namespace\n";
     print HSDUMP_OUT "#   Created by:  $::NAME (Ver $::VERSION) [",
-    # also note our own package version 
+    # also note our own package version
                      __PACKAGE__, " Ver $TKPING_LIB_VERSION]\n";
     print HSDUMP_OUT "#       Run by:  $realId $extraIdStr\n";
     print HSDUMP_OUT "#           on:  $dateTimeStr\n";
-    
+
     genHsArIniFile(\*HSDUMP_OUT, $topHashHsNm, $namespace);
-    
+
     print HSDUMP_OUT "\n";
     print HSDUMP_OUT "#\n";
     print HSDUMP_OUT "# $sep\n";
     print HSDUMP_OUT "#   End of FILE:  $outFName\n";
     print HSDUMP_OUT "# $sep\n";
-    
+
     close HSDUMP_OUT or
       SwengFatalMsg("Can't close $outFName: $!");
     return if (UTFatalOccurred());  # return if under unit-test!
@@ -1154,7 +1161,7 @@ sub Hash2IniFile($$;$)
 
 ## ----------------------------------------------------------------------------
 ## FUNCTION:
-##   IniFile2Hash -- populate hashes/arrays from named file, 
+##   IniFile2Hash -- populate hashes/arrays from named file,
 ##                   failing if file does not exist.  It returns the
 ##                   topLevel hash name (without the namespace prefix)
 ##
@@ -1284,7 +1291,7 @@ sub IniFile2Hash($;$)
 ##   &BackupFile(-force,filename,".dat",".BAK");
 ##
 ##-----------------------------------------------------------------------------
-sub BackupFile(@) 
+sub BackupFile(@)
 {
 	my @ARGV = @_;
 	DebugMsg("Called as: BackupFile(@ARGV)") if($traceCalls);
@@ -1314,36 +1321,36 @@ sub BackupFile(@)
 		$ARGC = @ARGV;
 	}
 	my ($msgText) = @ARGV;	# text is remainder of list
-		
+
 	if($ARGC < 3) {
 		FatalMsg("BackupFile(): CODE-ERROR- not enough parms provided\007");
 	}
 	my $newSuffix = pop @ARGV;
 	my $origSuffix = pop @ARGV;
 	my $filespec = pop @ARGV;
-	
+
 	DebugMsg("filespec=$filespec origSuffix=$origSuffix newSuffix=$newSuffix");
 	# NOTE: uses open/close pairs for better messaging when fail occurs
-	
+
 	open TEST_NBR1,"<$filespec" or
 		FatalMsg("Unable to backup [$filespec]: $!, Aborting!!\007");
 	close TEST_NBR1;
-	
+
 	my $baseName = Basename($filespec,$origSuffix);
 	my $dirName = Dirname($filespec);
 	my $newFspec = $dirName . "/" . $baseName . $newSuffix;
 	DebugMsg("baseName=$baseName dirName=$dirName newFspec=$newFspec");
-	
+
 	if(!$forceOverwrite) {
 		if(!(-e $newFspec && -w _ && -f _)) {
 			FatalMsg("Unable overwrite [$newFspec]: mod bits prevent, Aborting!!\007");
 		}
 	}
-	
+
 	open TEST_NBR2,">$newFspec" or
 		FatalMsg("Unable to backup to [$newFspec]: $!, Aborting!!\007");
 	close TEST_NBR2;
-	
+
 	system("cp -p $filespec $newFspec");
 	if(! -e $newFspec) {
 		FatalMsg("copy of $filespec to $newFspec Failed, Aborting!!\007");
@@ -1367,11 +1374,11 @@ sub DoCmdRetOutput($@@)
 	my $cmdStr = shift;
 	local *stdoutAr = shift;
 	local *stderrAr = shift;
-	
+
 	my $retCode = 0;	#  pre-clear return arrays
 	@stdoutAr = ();
 	@stderrAr = ();
-	
+
 	my $tmpDir = "/tmp/";
 	if($^O =~ /win32/i) {
 		if(exists $ENV{'TEMP'}) {
@@ -1385,11 +1392,11 @@ sub DoCmdRetOutput($@@)
 	my $stderrFname = "$tmpDir$::NAME.$$.err.tmp";
 	unlink $stdoutFname if (-f $stdoutFname);
 	unlink $stderrFname if (-f $stderrFname);
-	
+
 	#  add our output files to desired command
 	$cmdStr .= " 1>$stdoutFname 2>$stderrFname";
 	$retCode = DoCmd($cmdStr);
-	
+
 	#  load output of non-zero length
 	if(-s $stdoutFname) {
 		@stdoutAr = File2Array($stdoutFname);
@@ -1397,17 +1404,17 @@ sub DoCmdRetOutput($@@)
 	if(-s $stderrFname) {
 		@stderrAr = File2Array($stderrFname);
 	}
-	
+
 	#  remove files if exist
 	if (-f $stdoutFname && !defined $main::opt_debug) {
-		unlink $stdoutFname or 
+		unlink $stdoutFname or
 			Msg(-err,"DoCmdRetOutput() Failed tmp-file remove:$!\n\t- [$stdoutFname]");
 	}
 	if (-f $stderrFname && !defined $main::opt_debug) {
 		unlink $stderrFname or
 			Msg(-err,"DoCmdRetOutput() Failed tmp-file remove:$!\n\t- [$stderrFname]");
 	}
-	
+
 	return $retCode;
 }
 
@@ -1469,7 +1476,7 @@ sub DoCmd($)
 ##  FUNCTION: GeneralMkdir()
 ##
 ##	   mkdir wrapped with error reporting!  Exits if fails!
-## 
+##
 ##  SYNOPSIS:
 ##   GeneralMkdir($)
 ##
@@ -1477,10 +1484,10 @@ sub DoCmd($)
 ##   GeneralMkdir("/new/directory/to/make");
 ##
 ## ---------------------------------------------------------------------
-sub GeneralMkdir($) 
+sub GeneralMkdir($)
 {
 	my $dirToMake = shift;
-	
+
 	my $mkdirCmd = Cmd4thisOsRev("/bin/mkdir","/usr/bin/mkdir");
 	if(! -d $dirToMake) {
 		my $cmdTxt = "$mkdirCmd -p $dirToMake";
@@ -1499,7 +1506,7 @@ sub GeneralMkdir($)
 ##  FUNCTION: GetUserNames()
 ##
 ##	   return real and effective user ID's
-## 
+##
 ##  SYNOPSIS:
 ##   ($,$) = GetUserNames()
 ##
@@ -1507,25 +1514,25 @@ sub GeneralMkdir($)
 ##   ($realId,$effId) = GetUserNames();
 ##
 ## ---------------------------------------------------------------------
-sub GetUserNames() 
+sub GetUserNames()
 {
 	my $realIdNbr = $<;
-	
+
 	my $realId = "?{win32}?";
 	my $effId = "?{win32}?";
 	my $effIdNbr = $>;
-	
+
 	if($^O !~ /win32/i) {
 		$realId = (getpwuid($realIdNbr))[0];
 		$effId = (getpwuid($effIdNbr))[0];
 	}
-	
+
 	if(exists $ENV{'USERNAME'}) {
 		$realId = $ENV{'USERNAME'};
 		$effId = $realId;
 		DebugMsg("tkpingLib::GetUserNames() ENV{USERNAME}: realId=[$realId] effId=[$effId]");
 	}
-	
+
 	#
 	#  Apparently 5.003 (and earlier?) for hpux... had problems
 	#   identifying real-user-id  "$<"...
@@ -1546,7 +1553,7 @@ sub GetUserNames()
 ##
 ##	   id and return proper form of command for this HP-UX rev
 ##       terminate if NO correct one found!
-## 
+##
 ##  SYNOPSIS:
 ##   $ = Cmd4thisOsRev($$);
 ##
@@ -1554,11 +1561,11 @@ sub GetUserNames()
 ##   my $rmCmd = Cmd4thisOsRev("/bin/rm","/usr/bin/rm");
 ##
 ## ---------------------------------------------------------------------
-sub Cmd4thisOsRev($$) 
+sub Cmd4thisOsRev($$)
 {
 	my $cmdLocnA = shift;
 	my $cmdLocnB = shift;
-	
+
 	my $properCmd = "";
 	if(-x $cmdLocnA) {
 		$properCmd = $cmdLocnA;
@@ -1575,7 +1582,7 @@ sub Cmd4thisOsRev($$)
 ##  FUNCTION: EnsureDirExists()
 ##
 ##	   check for dir.  Fail if doesn't exist
-## 
+##
 ##  SYNOPSIS:
 ##   EnsureDirExists($);
 ##
@@ -1583,13 +1590,13 @@ sub Cmd4thisOsRev($$)
 ##   EnsureDirExists($BINDIR,"BINDIR");
 ##
 ## ---------------------------------------------------------------------
-sub EnsureDirExists($$) 
+sub EnsureDirExists($$)
 {
 	my $desiredDir = shift;
 	my $varName = shift;
 
 	DebugMsg("EnsureDirExists($varName=[$desiredDir])");
-	FatalMsg("Directory NOT found [$desiredDir].\007") 
+	FatalMsg("Directory NOT found [$desiredDir].\007")
 		unless -d $desiredDir;
 }
 
@@ -1599,7 +1606,7 @@ sub EnsureDirExists($$)
 ##
 ##	   check for Environment Variables being set.  Fail if NOT or
 ##       return it's value if was.
-## 
+##
 ##  SYNOPSIS:
 ##   $ = EnsureVariableExists($);
 ##
@@ -1610,7 +1617,7 @@ sub EnsureDirExists($$)
 sub EnsureVariableExists($)
 {
 	my $envVarNm = shift;
-	
+
 	if(!exists $main::ENV{$envVarNm}) {
 		FatalMsg("Required environment variable NOT set [$envVarNm], Aborting!\007");
 	}
@@ -1620,7 +1627,7 @@ sub EnsureVariableExists($)
 }
 
 ## ----------------------------------------------------------------------------
-## FUNCTION: DoCmdRetSingleLine - system() call with advanced ret-code 
+## FUNCTION: DoCmdRetSingleLine - system() call with advanced ret-code
 ##           analysis and single line returned from STDOUT.
 ##
 ## SYNOPSIS: $ = DoCmdRetSingleLine([-force,]$)
@@ -1637,7 +1644,7 @@ sub DoCmdRetSingleLine(@)
 	local @txtAr = ();
 	local @errAr = ();
 
-	# note: pass all args on, including optional -force 
+	# note: pass all args on, including optional -force
 	# note: Passing @_ doesn't work on PC, use a string
 
 	my $cmd = join( " ", @_ );
@@ -1730,7 +1737,7 @@ sub ArrayRef2File($@)
 ##   $rc = 0 if (!RequireDir("BINDIR"));
 ##
 ##   Note that '$rc &&= RequireDir("BINDIR")' won't allow calls to RequireDir
-##   after first error! 
+##   after first error!
 ##
 ## ----------------------------------------------------------------------------
 sub RequireDir($)
@@ -1817,10 +1824,10 @@ sub Assert($;@)
 sub RequireParm($$$)
 {
     my ($optNm, $optValue, $optText) = @_;
-    
+
     my $fullOptName = "main::opt_${optNm}";
     my $rc = 1;     # hope for the best
-    
+
     #  detect error condition (non-renovated scripts!)
     if(defined $main::NOTSET_STR && $main::NOTSET_STR ne $NOTSET_STR) {
         Msg(-err,"Mismatched use of NOTSET_STR (now defined in tkpingLib.pm!");
